SelectionGranularity

Enum SelectionGranularity 

pub(crate) enum SelectionGranularity {
    Position,
    Word,
    LineIgnoringSoftWrap,
}
A selection granularity to use when selecting via mouse button events.

Variants



Position

Select a single selection focus node position. This is created via single primary click or middle clicks.



Word

Select a word at the target point. This is created via double primary clicks.



LineIgnoringSoftWrap

Select to the paragraph boundaries or to a hard line break, whatever comes first. This is triggered via triple primary clicks.

Implementations

Source

impl SelectionGranularity

pub(crate) fn from_mouse_event(mouse_event: &MouseEvent) -> Option<Self>